@@ -120,12 +120,13 @@ class Plywood(object):
     RTL = 2
     PRECEDENCE = {
         'high':  (100, LTR),
+        # '|':     (18, LTR),
         '[]':    (17, LTR),
         '.':     (17, LTR),
+        '@':     (17, LTR),
         '()':    (16, LTR),
         '**':    (14, RTL),
         'unary': (13, RTL),
-        '&':     (12, LTR),
         '|':     (11, LTR),
         '//':    (10, LTR),
         '/':     (10, LTR),
@@ -133,8 +134,6 @@ class Plywood(object):
         '+':     (9, LTR),
         '-':     (9, LTR),
         '%':     (8, LTR),
-        '<<':    (7, LTR),
-        '>>':    (7, LTR),
         '==':    (5, LTR),
         '!=':    (5, LTR),
         '<=':    (5, LTR),
@@ -152,7 +151,6 @@ class Plywood(object):
         '/=':    (2, RTL),
         '*=':    (2, RTL),
         '%=':    (2, RTL),
-        '.=':    (2, RTL),
         '|=':    (2, RTL),
         'or=':   (2, RTL),
         '&=':    (2, RTL),
