@@ -7,6 +7,7 @@ from element import output_element
 class PlywoodValue(object):
     def __init__(self, location):
         self.location = location
+        self.suppress_nl = False
 
     def get_attr(self, attr, scope):
         raise Exception("{self!r} has no property {attr!r}".format(self=self, attr=attr))
@@ -31,7 +32,9 @@ class PlywoodValue(object):
 
     def run(self, states, scope):
         if Continue() in states:
-            return [Continue()], self.get_value(scope)
+            if self.suppress_nl:
+                states.append(SuppressOneNewline())
+            return states, self.get_value(scope)
         else:
             raise Exception(''.join(states))
 
@@ -88,7 +91,7 @@ class PlywoodBlock(PlywoodValue):
                         retval += unicode(cmd_ret)
                         suppress_newline = SuppressNewline() in states or SuppressOneNewline() in states
                         if not self.inline and not suppress_newline:
-                            retval += scope['__separator']
+                            retval += scope['__runtime'].options['separator']
                         try:
                             states.remove(SuppressOneNewline())
                         except ValueError:
@@ -113,6 +116,9 @@ class PlywoodVariable(PlywoodValue):
     def run(self, states, scope):
         return self.get_value(scope).run(states, scope)
 
+    def call(self, states, scope, arguments, block):
+        return self.get_value(scope).call(states, scope, arguments, block)
+
     def get_name(self):
         return self.name
 
@@ -142,6 +148,9 @@ class PlywoodVariable(PlywoodValue):
     def get_attr(self, attr, scope):
         return self.get_value(scope).get_attr(attr, scope)
 
+    def get_item(self, attr, scope):
+        return self.get_value(scope).get_item(attr, scope)
+
     def __eq__(self, other):
         return isinstance(other, PlywoodVariable) and other.name == self.name
 
@@ -151,6 +160,10 @@ class PlywoodVariable(PlywoodValue):
     __str__ = lambda self: self.name
 
 
+class uni(unicode):
+    pass
+
+
 class PlywoodString(PlywoodValue):
     def __init__(self, location, value, triple=False):
         self.triple = triple
@@ -159,7 +172,7 @@ class PlywoodString(PlywoodValue):
             # unindent
             lang, value = PlywoodString.unindent(value, return_lang=True)
             self.lang = lang
-        self.value = value
+        self.value = uni(value)
         super(PlywoodString, self).__init__(location)
 
     @staticmethod
@@ -280,6 +293,10 @@ class PlywoodPythonValue(PlywoodValue):
         attr = attr.get_name()
         if hasattr(val, attr):
             return getattr(val, attr)
+        try:
+            return val[attr]
+        except (KeyError, TypeError):
+            pass
         return None
 
     def set_item(self, attr, value, scope):
@@ -287,7 +304,7 @@ class PlywoodPythonValue(PlywoodValue):
 
     def get_item(self, attr, scope):
         val = self.python_value(scope)
-        key = attr.get_name()
+        key = attr.python_value(scope)
         if key in val:
             return val[key]
         return None
@@ -438,6 +455,9 @@ class PlywoodCallOperator(PlywoodOperator):
         else:
             raise Exception(''.join(states))
 
+    def call(self, states, scope, arguments, block):
+        return self.left.get_value(scope).run(states, scope)
+
     def get_value(self, scope):
         return self.run([Continue()], scope)[1]
 
@@ -815,7 +835,7 @@ class PlywoodFunction(PlywoodCallable):
         if self.accepts_block:
             def inside(indent=False):
                 if indent:
-                    return scope['__indent'](block.python_value(scope))
+                    return scope['__runtime'].indent(block.python_value(scope))
                 return block.python_value(scope)
             retval = self.fn(inside, *args, **kwargs)
         else:
